/*
 * Copyright (c) 2012, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @summary Basic test for ModuleArchitecture matching
 */

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import org.openjdk.jigsaw.ModuleArchitecture;

public class ModuleArchitectureTest {

    static List<ModuleArchitecture> oses = new ArrayList<>( Arrays.asList(
        ModuleArchitecture.createFromOS("solaris"),
        ModuleArchitecture.createFromOS("linux"),
        ModuleArchitecture.createFromOS("windows"),
        ModuleArchitecture.createFromOS("macosx"),
        ModuleArchitecture.createFromOS("freebsd"),
        ModuleArchitecture.createFromOS("hp-ux") ));

    static List<ModuleArchitecture> archs = new ArrayList<>( Arrays.asList(
        ModuleArchitecture.createFromArch("sparc"),
        ModuleArchitecture.createFromArch("sparcv9"),
        ModuleArchitecture.createFromArch("i386"),
        ModuleArchitecture.createFromArch("x86"),
        ModuleArchitecture.createFromArch("amd64"),
        ModuleArchitecture.createFromArch("x86_64"),
        ModuleArchitecture.createFromArch("ia64"),
        ModuleArchitecture.createFromArch("arm"),
        ModuleArchitecture.createFromArch("ppc"),
        ModuleArchitecture.createFromArch("pa_risc2.0") ));

    static List<ModuleArchitecture> platforms = new ArrayList<>( Arrays.asList(
        ModuleArchitecture.create("solaris", "sparc"),
        ModuleArchitecture.create("solaris", "sparcv9"),
        ModuleArchitecture.create("solaris", "x86"),
        ModuleArchitecture.create("solaris", "amd64"),
        ModuleArchitecture.create("linux", "i386"),
        ModuleArchitecture.create("linux", "arm"),
        ModuleArchitecture.create("linux", "ppc"),
        ModuleArchitecture.create("linux", "amd64"),
        ModuleArchitecture.create("linux", "x86_64"),
        ModuleArchitecture.create("linux", "ia64"),
        ModuleArchitecture.create("windows", "x86"),
        ModuleArchitecture.create("windows", "amd64"),
        ModuleArchitecture.create("macosx", "i386"),
        ModuleArchitecture.create("macosx", "ppc"),
        ModuleArchitecture.create("macosx", "x86_64"),
        ModuleArchitecture.create("freebsd", "i386"),
        ModuleArchitecture.create("hp-ux", "pa_risc2.0") ));

    static int failed;

    public static void main(String[] args) {
        for (ModuleArchitecture os : oses) {
            for (ModuleArchitecture platform : platforms) {
                if (platform.os().equals(os.os()))
                    matches(platform, os);
                matches(ModuleArchitecture.ANY, platform);
                matches(ModuleArchitecture.ANY, os);
            }
        }
        for (ModuleArchitecture arch : archs) {
            for (ModuleArchitecture platform : platforms) {
                if (platform.arch().equals(arch.arch()))
                    matches(platform, arch);
                matches(ModuleArchitecture.ANY, platform);
                matches(ModuleArchitecture.ANY, arch);
            }
        }

        ModuleArchitecture sunos = ModuleArchitecture.createFromOS("SunOS");
        ModuleArchitecture sparc = ModuleArchitecture.createFromArch("sparc");
        matches(sunos, sparc);

        if (failed > 0)
            throw new RuntimeException("Failed " + failed + " tests: check output");
    }

    static void matches(ModuleArchitecture ma1, ModuleArchitecture ma2) {
        if (! (ma1.matches(ma2) && ma2.matches(ma1)) ) {
            failed++;
            System.out.printf("[%s] should match to [%s]%n", ma1, ma2);
        }
    }
}
